   /*-----------------------------------------------------------.   
  /                     ColorBlind correction                   /
  '-----------------------------------------------------------*/
// sources from sebbylive.com and Daltonize.Org adapted for sweetfx by ninjafada
float4 CBCPass( float4 colorInput, float2 tex )
{

	float3 Protanope1 = (0.0, 2.02344, -2.52581);
	float3 Protanope2 = (0.0, 1.0, 0.0);
	float3 Protanope3 = (0.0, 0.0, 1.0);
	
	float3 ERRtoMOD1 = (0.0, 0.0, 0.0);
	float3 ERRtoMOD2 = (0.7, 1.0, 0.0);
	float3 ERRtoMOD3 = (0.7, 0.0, 1.0);

	// this is converting from RGB to long/medium/short cones. mess with these for cool effects.
	float3 L = (17.8824f * colorInput.r) + (43.5161f * colorInput.g) + (4.11935f * colorInput.b);
	float3 M = (3.45565f * colorInput.r) + (27.1554f * colorInput.g) + (3.86714f * colorInput.b);
	float3 S = (0.0299566f * colorInput.r) + (0.184309f * colorInput.g) + (1.46709f * colorInput.b);
	#if ( colorblind_mode  == 1)
	// this simulates protanopia
	float l = 0.0f * L + 2.02344f * M + -2.52581f * S;
	float m = 0.0f * L + 1.0f * M + 0.0f * S;
    float s = 0.0f * L + 0.0f * M + 1.0f * S;
	#endif
	
	#if ( colorblind_mode  == 2)
	// this simulates 	deuteranope
	
	float l = 1.0f * L + 0.0f * M + 0.0f * S;
    float m = 0.494207f * L + 0.0f * M + 1.24827f * S;
    float s = 0.0f * L + 0.0f * M + 1.0f * S;
	
	#endif
	#if ( colorblind_mode  == 3)
	// this simulates  tritanope
	
	float l = 1.0f * L + 0.0f * M + 0.0f * S;
    float m = 0.0f * L + 1.0f * M + 0.0f * S;
    float s = -0.395913f * L + 0.801109f * M + 0.0f * S;
	
	#endif
	//this converts back to rgba
	float4 returned;
	returned.r = (0.0809444479f * l) + (-0.130504409f * m) + (0.116721066f * s);
	returned.g = (-0.0102485335f * l) + (0.0540193266f * m) + (-0.113614708f * s);
	returned.b = (-0.000365296938f * l) + (-0.00412161469f * m) + (0.693511405f * s);
	returned.a = colorInput.a;
	
	float4 error;
	error = (colorInput - returned);
	
	float4 correct;
	correct.r = (error.r * 0.0) + (error.g * 0.0) + (error.b * 0.0);
	correct.g = (error.r * 0.7) + (error.g * 1.0) + (error.b * 0.0);
	correct.b = (error.r * 0.7) + (error.g * 0.0) + (error.b * 1.0);
	
	float4 final;
	final.r = colorInput.r + correct.r;
	final.b = colorInput.b + correct.b;
	final.g = colorInput.g + correct.g;
	final.a = colorInput.a;
	
	return final.rgba;
}